# Welcome to cnsr

[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

## Installation

The Python package `cnsr` can be installed from PyPI:

```
python -m pip install cnsr
```

## Acknowledgments

TODO.
